<?php
// $Id

// This function borrows some code from template_preprocess_block_admin_display_form
function template_preprocess_composite_zones_form(&$variables) {
  $layout_zones = $variables['form']['#zones'];
  $layout_zones[COMPOSITE_ZONE_NONE] = t('Disabled');
  $variables['layout_zones'] = $layout_zones;
  
  foreach ($layout_zones as $key => $value) {
    // Highlight regions on page to provide visual reference.
    // drupal_set_content($key, '<div class="block-region">'. $value .'</div>');
    // Initialize an empty array for the region.
    $variables['zone_listing'][$key] = array();
  }
  $variables['zone_listing'][COMPOSITE_ZONE_NONE] = array();

  foreach (element_children($variables['form']) as $i) {
    $reference = &$variables['form'][$i];

    // Only take form elements that are references.
    if (isset($reference['id'])) {
      // Fetch zone for current block.
      $zone = $reference['zone']['#default_value'];

      // Set special classes needed for table drag and drop.
      $variables['form'][$i]['zone']['#attributes']['class'] = 'block-region-select block-region-'. $zone;
      $variables['form'][$i]['weight']['#attributes']['class'] = 'block-weight block-weight-'. $zone;

      $variables['zone_listing'][$zone][$i]->row_class = isset($reference['#attributes']['class']) ? $reference['#attributes']['class'] : '';
      $variables['zone_listing'][$zone][$i]->reference_modified = isset($reference['#attributes']['class']) && strpos($reference['#attributes']['class'], 'block-modified') !== FALSE ? TRUE : FALSE;
      $variables['zone_listing'][$zone][$i]->reference_title =  drupal_render($reference['info']);
      $variables['zone_listing'][$zone][$i]->zone_select = drupal_render($reference['zone']); //. drupal_render($block['theme']);
      $variables['zone_listing'][$zone][$i]->weight_select = drupal_render($reference['weight']);
      $variables['zone_listing'][$zone][$i]->data_widget = drupal_render($reference['data']);
      $variables['zone_listing'][$zone][$i]->checkbox = drupal_render($reference['checkbox']);
      $variables['zone_listing'][$zone][$i]->printed = FALSE;
    }
  }

  $variables['form_layout_settings'] = drupal_render($variables['form']['layout_settings']);
  $variables['form_submit'] = drupal_render($variables['form']);
}

/**
 * Implementation of template_preprocess_TEMPLATE().
 * Render a node layout.
 */
function template_preprocess_composite_layout(&$variables) {
  $layout = $variables['layout'];
  $node = $layout['node'];

  // Add this layout's css, if any.
  if ($layout['css']) {
    drupal_add_css($layout['css']);
  }

  // Fetch layout data.
  $layout['data'] = $node->composite_layout_data;

  // Call the appropriate theme('composite_layout...', ...) function.
  // However, because the number of arguments depends on the number
  // of zones in the layout layout, we have to use call_user_func_array.
  // Add in the theme hook name and the first two arguments
  $args = array('composite_layout_' . $layout['key'], $layout, $node->composite_content);

  // Preprocess references.
  $zones = array();
  $references = _composite_references_preprocess($node->composite_references, $layout['zones'], FALSE);
  // Build zones content temporary array. I'm not fond of this part of the
  // algorithm, but should suffice for a start.
  foreach (element_children($references) as $key) {
    $zone = $references[$key]['zone'];
    // Avoid PHP warnings.
    if (!isset($zones[$zone])) {
      $zones[$zone] = array();
    }
    $zones[$zone][] = &$references[$key];
  }

  // Render all zones and populate the composite_content array.
  foreach ($layout['zones'] as $zone => $useless) {
    $args[] = theme('composite_zone', array(
      'name' => $zone,
      'references' => isset($zones[$zone]) ? $zones[$zone] : array(),
    ), $node);
  }

  // Call the specific theme function for the given layout.
  $variables['content'] = call_user_func_array('theme', $args);
}

/**
 * Implementation of template_preprocess_TEMPLATE().
 * Render a layout zone.
 */
function template_preprocess_composite_zone(&$variables) {
  // Prepare content.
  $variables['content'] = '';
  // Iterate over references and render each one of them.
  foreach ($variables['zone']['references'] as &$reference) {
    $variables['content'] .= theme('composite_reference', $reference, $variables['node']);
  }
}

/**
 * Implementation of template_preprocess_TEMPLATE().
 * Render a zone reference.
 */
function template_preprocess_composite_reference(&$variables) {
  $variables['content'] = composite_invoke_referenceapi($variables['reference'], 'view', $variables['node']);
}

function theme_composite_layout_radios($element) {
  return theme('radios', $element);
}

function theme_composite_layout_icon($file, $layout) {
  return '<img src="' . base_path() . $file . '" alt="' . $layout['template'] . '" class="composite-layout-icon" />';
}

function theme_composite_zones_preview($node) {
  if (isset($node->nid)) {
    $output = '<div class="preview">' . node_view($node, FALSE, FALSE) .'</div>';
    return $output;
  }
}

function theme_composite_node_title($title) {
  return '<div>' . $title . '</div>';
}
